@@ -348,7 +348,10 @@ def _traverse_file(
         tree = parse_from_strings(filename, code, context=context)
     except Exception as exp:  # pragma: no cover  # noqa: E722
         # If Cython can't parse this file, just skip it.
-        print(f'cant parse {filename}: {repr(exp)}')
+        print(
+            f'Skipping file {filename}, as it cannot be parsed. Error: '
+            f'{repr(exp)}',
+        )
         raise CythonParseError
     nodes = list(traverse(tree))
     imported_names: list[Token] = []
@@ -643,7 +646,7 @@ def sanitise_input(
     exclude_lines = {
         token.line
         for token in tokens
-        if token.name == 'NAME' and token.src == 'include'
+        if token.name == 'NAME' and token.src in ('include', 'DEF')
     }
     code = tokens_to_src(tokens)
     lines = {}
